1. [PACKAGE] package as a library so people can install it and run it
   1. people should be able to run it like this: `uvx filebundler`
   2. we'll use uv to make the build
2. [TEST] we haven't written any test
3. [DOCS] add pictures to README
4. [DOCS] make a video

